package com.example.aerospike;

import com.aerospike.client.AerospikeClient;
import com.aerospike.client.AerospikeException;
import com.aerospike.client.Bin;
import com.aerospike.client.Host;
import com.aerospike.client.Key;
import com.aerospike.client.Language;
import com.aerospike.client.Record;
import com.aerospike.client.Value;
import com.aerospike.client.policy.ClientPolicy;
import com.aerospike.client.policy.Policy;
import com.aerospike.client.policy.WritePolicy;
import com.aerospike.client.query.RecordSet;
import com.aerospike.client.query.Statement;
import com.aerospike.client.task.RegisterTask;

public class Main 
{
	public static void main( String[] args ) {
		Host[] hosts = new Host[] {
			new Host("192.168.1.11", 3000),
			new Host("192.168.1.12", 3000),
			new Host("192.168.1.13", 3000)
		};
		try (AerospikeClient client = new AerospikeClient(new ClientPolicy(), hosts)) {
			// 書き込み処理
			WritePolicy writepolicy = new WritePolicy();
			writepolicy.timeout = 5000;
			writepolicy.expiration = 3600;
			String namespace = "test";
			String setName = "fruit";
			Key key1 = new Key(namespace, setName, "001");
			Key key2 = new Key(namespace, setName, "002");
			Key key3 = new Key(namespace, setName, "003");

			Bin bin1 = new Bin("name", "orange");
			Bin bin2 = new Bin("price", 300);
			client.put(writepolicy, key1, bin1, bin2);

			Bin bin3 = new Bin("name", "banana");
			Bin bin4 = new Bin("price", 600);
			client.put(writepolicy, key2, bin3, bin4);

			Bin bin5 = new Bin("name", "apple");
			Bin bin6 = new Bin("price", 100);
			client.put(writepolicy, key3, bin5, bin6);

			// 読み込み処理
			Policy policy = new Policy();
			Record record1 = client.get(policy, key1);
			Record record2 = client.get(policy, key2);
			Record record3 = client.get(policy, key3);
			Object val1 = record1.getValue("name");
			Object val2 = record2.getValue("price");
			Object val3 = record3.getValue("name");

			System.out.println(val1.toString());
			System.out.println(val2.toString());
			System.out.println(val3.toString());

			RegisterTask task = client.register(policy, "udf/example.lua", "example.lua", Language.LUA);
			task.waitTillComplete();

			String result = (String) client.execute(writepolicy, key1, "example", "read", Value.get("name"));
			System.out.println(result);

			Statement stmt = new Statement();
			stmt.setNamespace(namespace);
			stmt.setSetName(setName);
			RecordSet rs = client.query(null, stmt);

			while (rs.next()) {
				Key key = rs.getKey();
				client.execute(writepolicy, key, "example", "price_increase");
			}
		} catch (AerospikeException e) {
			e.printStackTrace();
		}
	}
}
